When validation annotations are used directly in the REST service methods, ConcurredModificationExceptions sporadically occur in the
toString method of ResteasyViolationException.

The exception occurs when, for example, the exception is logged via an asynchronous logger and converted in an ExceptionMapper.
It is possible that two threads call the toString method at the same time. (e.g. via printStacktrace)

Stacktrace:
```
java.util.ConcurrentModificationException
	at java.base/java.util.ArrayList$Itr.checkForComodification(ArrayList.java:1043)
	at java.base/java.util.ArrayList$Itr.next(ArrayList.java:997)
	at org.jboss.resteasy.api.validation.ResteasyViolationException.toString(ResteasyViolationException.java:212)
````

Because the problem occurs only sporadically, the concurrency problem was isolated in the toString method in the reproducer. However, the exception is created in RestEasy itself, so it is not possible for the services to override the behavior and, for example, use a different constructor or call the toString method directly after creating the exception.

In order to test this:

```
export JAVA_HOME=/path/to/jdk
mvn clean test
```